# frozen_string_literal: true

require_relative 'signed_request'

module Plagiarism
  module Client
    class Report
      class << self
        include SignedRequest

        DATETIME_FIELDS = %w[
          created_at
          completed_at
        ].freeze

        def create(data = {})
          structed post('/reports', body: data)
        end

        def show(report_id)
          structed get("/reports/#{report_id}")
        end

        def from_params(params)
          structed params
        end

        private

        def structed(data = {})
          obj = OpenStruct.new(data)

          DATETIME_FIELDS.each do |field|
            next if obj[field].blank? || !obj[field].is_a?(String)
            obj[field] = Time.zone.parse(obj[field])
          end

          obj
        end
      end
    end
  end
end
